import datetime
from finops_crawler import aws, credentials_provider

credentials = credentials_provider.api()
aws_costs_client = aws.costs_api(*credentials.get_credentials('aws'))

today = datetime.datetime.now().date()
seven_days_ago = today - datetime.timedelta(days=7)

cost_data = aws_costs_client.get_cost(seven_days_ago, today)

print(cost_data)



import os
import yaml

class CredentialsProvider:

    def __init__(self, credentials_file = 'credentials_config.yml'):
        current_dir = os.path.dirname(os.path.abspath(__file__))
        credentials_path = os.path.join(current_dir, credentials_file)

        with open(credentials_path, 'r') as f:
            try:
                self.config = yaml.safe_load(f)
            except yaml.YAMLError as exc:
                print(exc)

    def get_credentials(self, platform, quiet=False):
        creds = self.config.get(platform)
        if not creds:
            raise ValueError(f"No configuration found for {platform}")
        values = []
        errors = []
        for f in creds['fields']:
            value = os.getenv(f['key'])
            if not value:
                errors.append(f['key'])
                continue
            values.append(value)
        if len(errors) > 0:
            if not quiet:
                raise ValueError(f"Missing environment variable(s) for the following: {', '.join(errors)}")
            return None
        else:
            return tuple(values)

    def get_credential_list(self):
        available_keys = []
        for platform in self.config.keys():
            platform_keys_exist = self.get_credentials(platform, quiet=True)
            if platform_keys_exist:
                available_keys.append(platform)
        return available_keys

        


import datetime
from finops_crawler import openai, credentials_provider

credentials = credentials_provider.api()

openai_costs_client = openai.api(*credentials.get_credentials('openai'))

today = datetime.datetime.now().date()
seven_days_ago = today - datetime.timedelta(days=7)

# cost_data = openai_costs_client.get_cost(seven_days_ago, today)

# print(cost_data)



import datetime
from finops_crawler import azure, credentials_provider

credentials = credentials_provider.api()

azure_costs_client = azure.costs_api(*credentials.get_credentials('azure'))

# Get all subscription ids
subscription_ids = azure_costs_client.get_all_subscriptions()

today = datetime.datetime.now().date()
seven_days_ago = today - datetime.timedelta(days=7)

# Fetch cost and usage data for each subscription
for subscription_id in subscription_ids:
    print(f"Subscription_id: {subscription_id}")

    # cost_data = azure_costs_client.get_cost(subscription_id, seven_days_ago, today)
    cost_data = azure_costs_client.get_cost_detailed(subscription_id, seven_days_ago, today)
    print(cost_data)
